(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: umlmon_config.mli 188 2005-10-14 11:40:29Z gerd $ *)

open Umlmon_types

val read_global_config : unit -> umlglobalspec
  (* Reads the [GLOBAL] section of /etc/umlmon *)

val read_vm_config : string -> umlspec
  (* Reads the config section for the VM instance, merges /etc/umlmon and the
   * user-supplied configuration.
   *)

val write_vm_config : string -> umlspec -> unit
  (* Writes the config section of the VM instance *)

val get_inifile : ?priv:bool -> string -> umlspec -> Inifiles.inifile
  (* Returns the config section of the VM instance. The [inifile] object is not
   * connected to any reasonable file.
   *
   * [priv]: If true, privileged parameters are included in the result. Defaults to
   * false.
   *)

val vm_list : unit -> string list
  (* Returns the existing VMs *)

val proc_config_get :
  umlstatus ->
  Rpc_server.session ->
  unit ->
  (Umlmonctrl_aux.config_param_set -> unit) ->
    unit
  (* Implements the [config_get] procedure *)

val proc_config_set :
  umlstatus ->
  Rpc_server.session ->
  Umlmonctrl_aux.config_param_set ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [config_set] procedure *)

val proc_config_hot_add :
  umlstatus ->
  Rpc_server.session ->
  Umlmonctrl_aux.config_params ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [config_hot_add] procedure *)

val proc_config_hot_remove :
  umlstatus ->
  Rpc_server.session ->
  Umlmonctrl_aux.config_params ->
  (Umlmonctrl_aux.r_simple -> unit) ->
    unit
  (* Implements the [config_hot_remove] procedure *)
